@@ -5,6 +5,7 @@ mod positions;
 #[macro_use] extern crate investments;
 #[macro_use] extern crate maplit;
 
+use std::fs::File;
 use std::io::{self, Write};
 use std::path::Path;
 use std::process;
@@ -45,12 +46,12 @@ fn main() {
     }
 }
 
-fn main_inner(global: GlobalOptions, parser: Box<Parser>) -> EmptyResult {
+fn main_inner(global: GlobalOptions, parser: Parser) -> EmptyResult {
     let config_dir_path = Path::new(&global.config_dir);
     let config_path = config_dir_path.join("config.yaml");
 
     let mut config = Config::load(config_path.to_str().unwrap()).map_err(|e| format!(
-        "Error while reading {:?} configuration file: {}.", config_path, e))?;
+        "Error while reading {:?} configuration file: {}", config_path, e))?;
     config.db_path = config_dir_path.join("db.sqlite").to_str().unwrap().to_owned();
 
     let (command, action) = parser.parse(&mut config)?;
@@ -107,6 +108,12 @@ fn run(config: Config, command: &str, action: Action) -> EmptyResult {
         },
 
         Action::Metrics(path) => metrics::collect(&config, &path)?,
+
+        Action::ShellCompletion {path, data} => {
+            write_shell_completion(&path, &data).map_err(|e| format!(
+                "Failed to write {:?}: {}", path, e))?;
+            TelemetryRecordBuilder::new()
+        },
     };
 
     if let Some(telemetry) = telemetry.as_ref() {
@@ -115,3 +122,7 @@ fn run(config: Config, command: &str, action: Action) -> EmptyResult {
 
     Ok(())
 }
+
+fn write_shell_completion(path: &Path, data: &[u8]) -> EmptyResult {
+    Ok(File::create(path)?.write_all(data)?)
+}
\ No newline at end of file
