@@ -4,8 +4,7 @@
 use crate::commissions::{
     CommissionSpec, CommissionSpecBuilder, TradeCommissionSpecBuilder,
     TransactionCommissionSpecBuilder, CumulativeCommissionSpecBuilder};
-#[cfg(test)] use crate::currency::{Cash, MultiCurrencyCashAccount};
-#[cfg(test)] use crate::currency::converter::CurrencyConverter;
+#[cfg(test)] use crate::currency::{Cash, converter::CurrencyConverter};
 #[cfg(test)] use crate::types::TradeType;
 
 pub fn investor() -> CommissionSpec {
@@ -56,7 +55,7 @@ mod tests {
     fn investor(trade_type: TradeType) {
         let converter = CurrencyConverter::mock();
         let mut calc = CommissionCalc::new(
-            converter, super::investor(), Cash::new("RUB", dec!(0))).unwrap();
+            converter, super::investor(), Cash::zero("RUB")).unwrap();
 
         let date = date!(2020, 7, 27);
 
@@ -109,7 +108,7 @@ mod tests {
         let mut additional = HashMap::new();
         if depositary != 0 {
             // Actually the date is the date of the first trade
-            let commissions = MultiCurrencyCashAccount::new_from(Cash::new(currency, depositary.into()));
+            let commissions = Cash::new(currency, depositary.into()).into();
             additional.insert(date!(2020, 7, 1), commissions);
         }
         assert_eq!(calc.calculate().unwrap(), additional);
@@ -119,7 +118,7 @@ mod tests {
     fn trader_mixed_currency(trade_type: TradeType) {
         let converter = CurrencyConverter::mock();
         let mut calc = CommissionCalc::new(
-            converter, super::trader(), Cash::new("RUB", dec!(0))).unwrap();
+            converter, super::trader(), Cash::zero("RUB")).unwrap();
 
         let date = date!(2020, 12, 10);
         assert_eq!(
@@ -143,7 +142,7 @@ mod tests {
         assert_eq!(calc.calculate().unwrap(), hashmap!{
             // Depositary commission
             // Actually the date is the date of the first trade
-            date!(2021, 1, 1) => MultiCurrencyCashAccount::new_from(Cash::new("RUB", dec!(290))),
+            date!(2021, 1, 1) => Cash::new("RUB", dec!(290)).into(),
         });
     }
 
@@ -151,7 +150,7 @@ mod tests {
     fn premium(trade_type: TradeType) {
         let converter = CurrencyConverter::mock();
         let mut calc = CommissionCalc::new(
-            converter, super::premium(), Cash::new("RUB", dec!(0))).unwrap();
+            converter, super::premium(), Cash::zero("RUB")).unwrap();
 
         let date = date!(2021, 2, 20);
 
